@@ -545,8 +545,8 @@ void                swish_utf8_next_chr( xmlChar *s, int *i );
 void                swish_utf8_prev_chr( xmlChar *s, int *i );
 xmlChar *           swish_str_escape_utf8( xmlChar *utf8 );
 xmlChar *           swish_str_unescape_utf8( xmlChar *ascii );
-wchar_t *           swish_utf8_to_wchar(xmlChar * str);
-xmlChar *           swish_wchar_to_utf8(wchar_t * str);
+wchar_t *           swish_locale_to_wchar(xmlChar * str);
+xmlChar *           swish_wchar_to_locale(wchar_t * str);
 wchar_t *           swish_wstr_tolower(wchar_t *s);
 xmlChar *           swish_str_tolower(xmlChar *s );
 xmlChar *           swish_utf8_str_tolower(xmlChar *s);
